/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

/**
 * Browser entry point for AWS IoT SDK.
 * @packageDocumentation
 * @module aws-iot-device-sdk
 * @mergeTarget
 */

import {
    auth,
    http,
    io,
    iot,
    mqtt,
    mqtt5
} from 'aws-crt/dist.browser/browser';

export {
    auth,
    http,
    io,
    iot,
    mqtt,
    mqtt5
}
